'use strict';

module.exports = function(api, opts) {
  var plugins = [
    require('@babel/plugin-transform-destructuring'),
    require('@babel/plugin-proposal-object-rest-spread'),
    require('@babel/plugin-transform-runtime'),
    require('@babel/plugin-syntax-dynamic-import'),
    require('babel-plugin-jsx-control-statements'),
    [require.resolve('babel-plugin-module-resolver'), {root: ['./src']}]
  ];

  var env = process.env.BABEL_ENV || process.env.NODE_ENV;
  if (env !== 'development' && env !== 'production' && env !== 'test') {
    throw new Error(
      'Using `babel-preset-abyss` requires that you specify `NODE_ENV` or ' +
      '`BABEL_ENV` environment variables. Valid values are "development", ' +
      '"test", and "production". Instead, received: ' + JSON.stringify(env) + '.'
    );
  }

  if (env === 'development') {
    // The following two plugins are currently necessary to make React warnings
    // include more valuable information. They are included here because they are
    // currently not enabled in babel-preset-react. See the below threads for more info:
    // https://github.com/babel/babel/issues/4702
    // https://github.com/babel/babel/pull/3540#issuecomment-228673661
    // https://github.com/facebookincubator/create-react-app/issues/989
    plugins.push.apply(plugins, [
      // Adds component stack to warning messages
      require.resolve('@babel/plugin-transform-react-jsx-source'),
      // Adds __self attribute to JSX which React will use for some warnings
      require.resolve('@babel/plugin-transform-react-jsx-self')
    ]);
  } else if (env === 'production') {
    plugins.push.apply(plugins, [
      [require('@babel/plugin-transform-classes'), {loose: true}],
      [require('babel-plugin-transform-react-remove-prop-types'), {removeImport: true}]
    ]);
  }

  return {
    presets: [
      require('@babel/preset-env'),
      require('@babel/preset-react')
    ],
    plugins: plugins
  }
};
